/*
** Module   : ToggleBoxImpl.java
** Abstract :
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20140610 Initial implementation.
*/

package com.goldencode.p2j.ui.chui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * Specific implementation of a "toggle box" with a text label for CHUI.
 */
@SuppressWarnings("unchecked")
public class ToggleBoxImpl
extends ToggleBox
{
   /**
    * This constructor creates a toggle-box with a given text label.
    * 
    * @param   owner
    *          The parent container, frame or dialog which will include this toggle-box.
    * @param   text
    *          The string to be used as the toggle box text label.
    */
   ToggleBoxImpl(Container owner, String text) 
   {
      super(owner, text);
   }

   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   cfg
    *          Configuration data.
    */
   public ToggleBoxImpl(ComponentConfig cfg)
   {
      super(cfg);
   }
   
   /**
    * Draw the button. Called by this ToggleBox's parent container.
    */
   @Override
   public void draw()
   {
      // get the absolute origin of this component
      Point origin = screenLocation();

      screen().at(origin);
      Color dc = UiUtils.getDcolor(this);
      Color pf = config().getPfcolor();

      // obtain the full text of the button's label
      String ct = textLabel();
      
      // calculate the total size of the button
      int bSize = width();
      
      // calculate the max size of the text part
      int tSize = bSize - 3;
      
      // calculate the actual text length (may be shorter or longer than the
      // text size)
      int tActual = ct.length(); 
      
      StringBuffer sb = new StringBuffer();
      
      // there is at least always the check-box with or without selection
      drawCheckBox(isEnabled() && widgetFocused, pf, dc);

      if (tSize > 0)
      {
         if (tSize < tActual)
         {
            // right truncate the text
            sb.append(ct.substring(0, tSize));
         }
         else // if (tSize == tActual)
         {
            // we are just big enough to hold the full text
            sb.append(ct);
         }
/*         else
         {
            // we must pad with spaces (if there an even number of spaces
            // then the left and right sides will have the same number, if
            // odd then the right side will have the extra space)
            
            int spaces = tSize - tActual;
            int left   = spaces / 2; 
            int right  = (spaces % 2) > 0 ? left + 1 : left;
            
            for (int i = 0; i < left; i++)
            {
               sb.append(" ");
            }
            
            sb.append(ct);
            
            for (int i = 0; i < right; i++)
            {
               sb.append(" ");
            }
         }*/
      }
      
      // actually draw the text label for check-box
      screen().append(sb.toString(), dc);

      // mnemonic processing
/*      if (underscore >= 0 && (underscore + 1) < bSize)
      {
         dc = UiUtils.getDcolor(this);

         // note that this draws in the non-reversed form whether selected
         // or not (this is the equivalent of a "highlight" in the selected
         // mode because the rest of the button was drawn in reverse video

         if (!highlighted())
            dc = dc.withUnderline();

         String mnemonic = ct.substring(underscore, underscore + 1);
         
         screen().at(origin.offset(1 + underscore, 0)).append(mnemonic, dc);
      }*/
   }

   /**
    * Draws check box itself ("[X]" or "[ ]").
    *
    * @param highlighted
    *        Indicates whether the button is highlighted.
    * @param pf
    *        The color used inside this check box under focus.
    * @param dc
    *        The color which corresponds DCOLOR attribute for this radio
    *        button.
    */
   private void drawCheckBox(boolean highlighted, Color pf, Color dc)
   {
      screen().append("[", highlighted ? pf : dc);
      screen().append(config().isChecked() ? "X" : " ", highlighted ? pf : dc);
      screen().append("]", highlighted ? pf : dc);
   }
}
